---
name: Documentation
about: Add/Improve Documentation
title: <Insert Title>
labels: documentation
assignees: ''

---

# Summary
<!---
A short summary on what of what needs to be documented or updated.
--->

# Details
<!---
A detailed description about what kind of documentation should be added and/or updated.
--->

## Background & Context
<!---
Why should this documentation be added/updated?

E.g.: Users are struggling to use this API and have repeatedly asked for some example code.
--->

## References
<!---
Further references to e.g. other information resources like links to specification(s), api docs etc.
--->

# Task(s)
<!---
A task list containing common tasks associated with this kind of issue, but also tasks specific to this issue.

e.g.:
- [ ] Update documentation of XYZ
- [ ] Bump version number
- [ ] Update changelog
- [ ] ...
--->
